Previna o câncer de mama - prótons da Califórnia
Description: Compreender as causas subjacentes e os fatores de risco do câncer de mama é fundamental para a prevenção. Saiba se você está em risco e quais medidas você pode tomar para prevenir o câncer de mama.

Prevenir seios
Câncer

Visão geral

Diagnóstico

sementes

Causas e Riscos

Estágios e notas

# Conheça as causas.
Entenda seus riscos.

Quando estiver na casa dos 20 anos, é importante manter o controle da sua saúde e fazer exames regulares às mamas. O câncer de mama é o câncer feminino mais comum em todo o mundo e cerca de 1 em 8 mulheres nos Estados Unidos será diagnosticada com ele em algum momento de suas vidas. Esse percentual aumenta para 72% para quem tem um BRCA1 mutação ou BRCA2 mutação. No entanto, o câncer de mama pode ser altamente curável, especialmente quando detectado precocemente.

## Principais causas do câncer de mama

O câncer é causado em grande parte por mutações ou alterações no material genético encontrado em suas células. Você nasce com algumas mutações, enquanto outras são adquiridas mais tarde na vida devido a erros no processo de replicação do gene. Na maioria dos casos, o câncer se desenvolve quando as células cessam suas funções normais e começam a permitir um crescimento rápido, não conseguem interromper o crescimento celular descontrolado ou cometem erros ao reparar erros de DNA. Lembre-se de que nem todas as mutações genéticas adquiridas ou herdadas se transformam em câncer.

## Fatores de risco comuns de câncer de mama

Embora os médicos tenham encontrado algumas correlações entre certas condições de saúde e casos diagnosticados, a maioria dos cânceres ocorre em pessoas sem quaisquer fatores de risco conhecidos. Sua melhor abordagem é gerenciar o que você pode controlar, mudar o que você pode e ficar atento às mudanças em sua saúde que podem ser a causa do câncer de mama.

- Idade: O câncer pode se desenvolver em qualquer idade, mas 2 em cada 3 cânceres de mama invasivos são encontrados em mulheres com 55 anos ou mais.
- Raça / etnia: A herança judaica Ashkenazi (Europa Oriental) pode colocá-lo em um risco maior. Mulheres brancas são ligeiramente mais propensas a desenvolver câncer de mama do que as de ascendência afro-americana, hispânica e asiática. No entanto, as mulheres afro-americanas são mais propensas a desenvolver um câncer de mama mais agressivo em uma idade mais jovem.
- Mutações genéticas herdadas: BRCA1, BRCA2 e CHEC2 as anormalidades podem ser atribuídas a 5-10% de todos os casos.
- História de família: Seu risco genético de câncer de mama dobra se você teve um parente de primeiro grau - irmã, mãe ou filha - diagnosticado com câncer de mama. Se você teve dois parentes de primeiro grau diagnosticados, seu risco é 5 vezes maior do que a média. Parentes de sangue diagnosticados antes dos 50 anos ou com câncer de mama triplo-nativo também podem aumentar o risco.
- Ciclos de parto e menstruação: Se você não teve uma gravidez a termo ou teve seu primeiro filho antes dos 30 anos, você pode ter um risco maior de ter câncer de mama. Começar a menstruação antes dos 12 anos e entrar na menopausa depois dos 55 também pode aumentar o risco.
- Estilo de vida e causas ambientais: Fumar, beber, falta de exercício, IMC acima de 25, inflamação crônica, baixos níveis de vitamina D, exposição excessiva ao sol ou a produtos químicos cancerígenos e sexo sem proteção podem contribuir para o desenvolvimento de células cancerosas.

## Dicas de prevenção do câncer de mama

Não existe uma estratégia comprovada de prevenção, mas adotar um estilo de vida saudável e tomar as medidas de saúde adequadas pode ajudar a reduzir o risco e melhorar a imunidade. Estudos recentes sugerem que a dieta é pelo menos parcialmente responsável por 30 a 40% de todos os cânceres.

### 1. Evite fumar

A fumaça contém compostos cancerígenos que podem causar câncer. Também o torna mais sujeito a efeitos colaterais relacionados ao tratamento. Se a radiação for necessária, você pode enfrentar um risco maior de desenvolver câncer de pulmão e / ou pneumonite.

### 2. Exercite-se regularmente

O exercício ajuda a controlar o açúcar no sangue e limita os níveis de insulina de um hormônio que pode afetar o modo como as células da mama crescem e desenvolvem mutações genéticas cancerígenas. Procure fazer pelo menos 150 minutos por semana de atividade aeróbica moderada ou 75 minutos de atividade aeróbica vigorosa.

### 3. Manter um peso saudável (abaixo de 25 IMC)

As células de gordura produzem estrogênio, que pode estimular o desenvolvimento e o crescimento de certos tipos de câncer de mama. As células de gordura extra também podem desencadear inflamação no corpo, que tem sido associada a uma maior chance de recorrência.

### 4. Siga uma dieta de prevenção do câncer de mama, escolhendo:

- Mantenha uma dieta rica em frutas e vegetais
- Escolha grãos inteiros, proteínas magras e leite desnatado e laticínios
- Remova a pele e a gordura de carnes, aves e peixes
- Limite de açúcar, carboidratos refinados e álcool
- Coma porções menores

### 5. Evite a exposição prejudicial a produtos químicos, toxinas, sol e outras radiações

Mais estudos estão começando a pesquisar as causas ambientais do câncer de mama e o impacto de certos produtos químicos encontrados em plásticos, cosméticos, alimentos, água e outros produtos de consumo. O uso de pesticidas, antibióticos e hormônios na produção de alimentos também pode desempenhar papéis.

### 6. Agende exames de mama anuais

A detecção precoce ainda é a melhor maneira de prevenir o crescimento ou a disseminação do câncer. Com taxas de sobrevida de 5 anos em torno de 100% para câncer de mama em estágio 0 e estágio 1, detectá-lo precocemente é fundamental.

### 7. Consulte um médico se você começar a sentir sintomas de câncer de mama, como:

- Fadiga
- A área protuberante ou espessa sentida sob a pele
- Perda ou ganho de peso não intencional
- Alterações na pele, como amarelecimento, escurecimento ou vermelhidão da pele
- Sangramento inexplicável, hematomas ou feridas que não cicatrizam
- Mudanças nos hábitos intestinais ou da bexiga
- Tosse persistente, dificuldade para respirar, indigestão ou desconforto após comer
- Rouquidão ou dificuldade para engolir
- Febres persistentes e inexplicáveis, suores noturnos ou dores musculares e / ou articulares

## Opções de tratamento preventivo do câncer de mama

Uma história familiar de câncer de mama e / ou uma mutação genética conhecida pode causar estresse e ansiedade em muitas mulheres. Em vez de esperar para ver, algumas mulheres optam por uma abordagem mais proativa e agressiva para reduzir suas chances. O mais comum é a remoção da (s) mama (s) e / ou ovários e a supressão do hormônio estrogênio ligado ao crescimento das células cancerosas. Embora não haja garantia, é bom se familiarizar com os tipos de tratamentos preventivos disponíveis.

### Mastectomia profilática

De acordo com o Instituto Nacional do Câncer, as mulheres que carregam um BRCA1 or BRCA2 a mutação genética e a opção por uma mastectomia preventiva podem reduzir o risco de desenvolvimento de câncer em 95%. Essa porcentagem cai ligeiramente para 90% para mulheres com um forte histórico familiar de câncer de mama. Durante esta operação cirúrgica, uma ou ambas as mamas serão removidas para reduzir o risco de formação de câncer na mama. A quantidade de tecido removido depende do tipo de mastectomia (por exemplo, total, preservação da pele e proteção do mamilo) realizada. A reconstrução da mama também pode ser uma opção durante ou após a cirurgia.

Saiba mais

### Remoção profilática de ovário

Este tipo de cirurgia dá às mulheres a opção de diminuir o risco sem causar grandes mudanças visíveis em seu corpo. A remoção dos ovários diminui a quantidade de estrogênio no corpo, o que ajuda a prevenir o câncer de mama que requer estrogênio para crescer. O Instituto Nacional do Câncer descobriu que esta cirurgia reduz o número de novos casos entre mulheres de alto risco em cerca de 50%. É importante observar que esse tipo de cirurgia só beneficia mulheres na pré-menopausa e elimina a possibilidade de ter filhos.

Saiba mais

### Terapia hormonal preventiva

Este tipo de tratamento é freqüentemente recomendado para aquelas que não foram diagnosticadas, mas que se acredita estarem em risco de câncer de mama ER e PR-positivo. Certos hormônios no sangue podem causar a formação desses cânceres no tecido mamário. Ao tomar esses medicamentos bloqueadores de hormônios, você pode diminuir a produção de estrogênio no sangue e interromper a estimulação das células mamárias. A terapia hormonal não afeta os tumores que são ER- e PR-negativos porque eles não são influenciados por hormônios.

Saiba mais

## Saiba mais sobre câncer de mama

Exames e diagnóstico para câncer de mama

Estágios e graus do câncer de mama

Opções de tratamento para câncer de mama

English
Afrikaans Albanian Amharic Arabic Armenian Azerbaijani Basque Belarusian Bengali Bosnian Bulgarian Catalan Cebuano Chichewa Chinese (Simplified) Chinese (Traditional) Corsican Croatian Czech Danish Dutch English Esperanto Estonian Filipino Finnish French Frisian Galician Georgian German Greek Gujarati Haitian Creole Hausa Hawaiian Hebrew Hindi Hmong Hungarian Icelandic Igbo Indonesian Irish Italian Japanese Javanese Kannada Kazakh Khmer Korean Kurdish (Kurmanji) Kyrgyz Lao Latin Latvian Lithuanian Luxembourgish Macedonian Malagasy Malay Malayalam Maltese Maori Marathi Mongolian Myanmar (Burmese) Nepali Norwegian Pashto Persian Polish Portuguese Punjabi Romanian Russian Samoan Scottish Gaelic Serbian Sesotho Shona Sindhi Sinhala Slovak Slovenian Somali Spanish Sudanese Swahili Swedish Tajik Tamil Telugu Thai Turkish Ukrainian Urdu Uzbek Vietnamese Welsh Xhosa Yiddish Yoruba Zulu

## Contato

Primeiro Nome*
Apelido*
Email*
Número de telefone*
Como você ficou sabendo sobre nós?*
Mensagem

## Registrar

- Primeiro Nome*
- Apelido*
- Título*
- Se outro, por favor especifique
- Afiliação*
- Rua e número Endereço Linha 2 Cidade Distrito
  CEP
- Email*
- Especialidade
- Se outro, por favor especifique
- Como você soube dessa atividade?
  - Brochura / cartão postal pelo correio
  - Anúncio por e-mail
  - Carta pessoal / convite
  - Diretor / Supervisor
  - Outros
- Se outro, por favor especifique
- Telefone Celular
  Este campo é para fins de validação e deve ser deixado inalterado.